@@ -11,7 +11,8 @@
 
 // this seems to be right based on
 // https://github.com/flatpak/xdg-desktop-portal/blob/309a1fc0cf2fb32cceb91dbc666d20cf0a3202c2/src/screen-cast.c#L955
-#define XDP_CAST_PROTO_VER 2
+#define XDP_CAST_PROTO_VER 4
+#define XDP_CAST_DATA_VER 1
 
 enum cursor_modes {
   HIDDEN = 1,
@@ -24,6 +25,12 @@ enum source_types {
   WINDOW = 2,
 };
 
+enum persist_modes {
+  PERSIST_NONE = 0,
+  PERSIST_TRANSIENT = 1,
+  PERSIST_PERMANENT = 2,
+};
+
 enum buffer_type {
   WL_SHM = 0,
   DMABUF = 1,
@@ -60,7 +67,8 @@ struct xdpw_frame {
 	bool y_invert;
 	uint64_t tv_sec;
 	uint32_t tv_nsec;
-	struct xdpw_frame_damage damage;
+	struct xdpw_frame_damage damage[4];
+	uint32_t damage_count;
 	struct xdpw_buffer *xdpw_buffer;
 	struct pw_buffer *pw_buffer;
 };
@@ -116,10 +124,10 @@ struct xdpw_screencast_context {
 	struct wl_list output_list;
 	struct wl_registry *registry;
 	struct zwlr_screencopy_manager_v1 *screencopy_manager;
-	struct zxdg_output_manager_v1 *xdg_output_manager;
 	struct wl_shm *shm;
 	struct zwp_linux_dmabuf_v1 *linux_dmabuf;
 	struct zwp_linux_dmabuf_feedback_v1 *linux_dmabuf_feedback;
+	struct zxdg_output_manager_v1 *xdg_output_manager;
 	struct xdpw_dmabuf_feedback_data feedback_data;
 	struct wl_array format_modifier_pairs;
 
@@ -130,6 +138,16 @@ struct xdpw_screencast_context {
 	struct wl_list screencast_instances;
 };
 
+struct xdpw_screencast_target {
+	struct xdpw_wlr_output *output;
+	bool with_cursor;
+};
+
+struct xdpw_screencast_restore_data {
+	uint32_t version;
+	const char *output_name;
+};
+
 struct xdpw_screencast_instance {
 	// list
 	struct wl_list link;
@@ -154,11 +172,10 @@ struct xdpw_screencast_instance {
 
 	// wlroots
 	struct zwlr_screencopy_frame_v1 *frame_callback;
-	struct xdpw_wlr_output *target_output;
+	struct xdpw_screencast_target *target;
 	uint32_t max_framerate;
 	struct zwlr_screencopy_frame_v1 *wlr_frame;
 	struct xdpw_screencopy_frame_info screencopy_frame_info[2];
-	bool with_cursor;
 	int err;
 	bool quit;
 	bool teardown;
@@ -168,6 +185,12 @@ struct xdpw_screencast_instance {
 	struct fps_limit_state fps_limit;
 };
 
+struct xdpw_screencast_session_data {
+	struct xdpw_screencast_instance *screencast_instance;
+	uint32_t cursor_mode;
+	uint32_t persist_mode;
+};
+
 struct xdpw_wlr_output {
 	struct wl_list link;
 	uint32_t id;
@@ -176,9 +199,12 @@ struct xdpw_wlr_output {
 	char *make;
 	char *model;
 	char *name;
+	int x;
+	int y;
 	int width;
 	int height;
 	float framerate;
+	enum wl_output_transform transformation;
 };
 
 void randname(char *buf);
@@ -195,4 +221,6 @@ enum spa_video_format xdpw_format_pw_strip_alpha(enum spa_video_format format);
 
 enum xdpw_chooser_types get_chooser_type(const char *chooser_type);
 const char *chooser_type_str(enum xdpw_chooser_types chooser_type);
+
+struct xdpw_frame_damage merge_damage(struct xdpw_frame_damage *damage1, struct xdpw_frame_damage *damage2);
 #endif /* SCREENCAST_COMMON_H */
